<?php
/*
  $Id: japanese.php,v 1.2 2005/09/22 01:20:08 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

//
// mb_internal_encoding() is set for PHP-4.3.x(Zend Multibyte)
//
// A compatible module is loaded for environment without mbstring-extension
//
if (extension_loaded('mbstring')) {
  mb_internal_encoding('EUC-JP'); // ɤ
} else {
  include_once(DIR_WS_LANGUAGES . $language . '/jcode.phps');
  include_once(DIR_WS_LANGUAGES . $language . '/mbstring_wrapper.php');
}

// look in your $PATH_LOCALE/locale directory for available locales..
// on RedHat try 'en_US'
// on FreeBSD try 'en_US.ISO_8859-1'
// on Windows try 'en', or 'English'
@setlocale(LC_TIME, 'ja_JP');
define('DATE_FORMAT_SHORT', '%Y/%m/%d');  // this is used for strftime()
define('DATE_FORMAT_LONG', '%Yǯ%B%e %A'); // this is used for strftime()
define('DATE_FORMAT', 'Y/m/d'); // this is used for date()
define('DATE_TIME_FORMAT', DATE_FORMAT_SHORT . ' %H:%M:%S');

////
// Return date in raw format
// $date should be in format mm/dd/yyyy
// raw date is in format YYYYMMDD, or DDMMYYYY
function tep_date_raw($date, $reverse = false) {
  if ($reverse) {
    return substr($date, 8, 2) . substr($date, 5, 2) . substr($date, 0, 4);
  } else {
    return substr($date, 0, 4) . substr($date, 5, 2) . substr($date, 8, 2);
  }
}

// if USE_DEFAULT_LANGUAGE_CURRENCY is true, use the following currency, instead of the applications default currency (used when changing language)
define('LANGUAGE_CURRENCY', 'JPY');

// Global entries for the <html> tag
define('HTML_PARAMS','dir="LTR" lang="ja"');

// charset for web pages and emails
define('CHARSET', 'EUC-JP');    // Shift_JIS / euc-jp / iso-2022-jp

// page title
//define('TITLE', 'osCommerce');  //å̾򵭽ҤƤ֥饦ɽȥˤʤޤ
define('TITLE', STORE_NAME);

// geta information
define('TEXT_GETA_LOGO', 'GETA');
define('TEXT_GETA_INFORMATION', 'Ϣ۷׻󥸥ʣǣţԣˡפϡȶ(IPA)»ܤŪ󵻽Ѱȡפθ̤Ǥ ');

// header text in includes/header.php
define('HEADER_TITLE_CREATE_ACCOUNT', 'Ⱥ');
define('HEADER_TITLE_MY_ACCOUNT', 'Ⱦ');
define('HEADER_TITLE_CART_CONTENTS', 'Ȥ򸫤');
define('HEADER_TITLE_CHECKOUT', '쥸˿ʤ');
define('HEADER_TITLE_TOP', 'ȥå');
define('HEADER_TITLE_CATALOG', '');
define('HEADER_TITLE_LOGOFF', '');
define('HEADER_TITLE_LOGIN', '');

// footer text in includes/footer.php
define('FOOTER_TEXT_REQUESTS_SINCE', 'ꥯ ('); // 'requests since'
define('FOOTER_TEXT_REQUESTS_SINCE_ADD', ' )'); // 'requests since' Add Japanese osCommerce

// text for gender
define('MALE', '');
define('FEMALE', '');
define('MALE_ADDRESS', ''); //Mr.
define('FEMALE_ADDRESS', '');   //Ms.

// text for date of birth example
define('DOB_FORMAT_STRING', 'yyyy-mm-dd');

// geta_search box text in includes/boxes/geta_search.php
define('BOX_HEADING_GETA_SEARCH', 'Ϣ۸');
define('BOX_GETA_SEARCH_TEXT', '<small>ɡʸϤ鸡</small>');
define('BOX_GETA_SEARCH_TEXT2', 'ɡʸϤϤƤ');
define('BOX_GETA_SEARCH_SUBMIT', 'Ϣ۸');
define('BOX_GETA_SEARCH_RESET', 'ꥢ');
define('BOX_MORE_GETA_THEMES', 'äȡ');

// categories box text in includes/boxes/categories.php
define('BOX_HEADING_CATEGORIES', 'ƥ꡼');

// manufacturers box text in includes/boxes/manufacturers.php
define('BOX_HEADING_MANUFACTURERS', '᡼');

// whats_new box text in includes/boxes/whats_new.php
define('BOX_HEADING_WHATS_NEW', '徦');
define('BOX_MORE_WHATS_NEW', 'ä...');

// quick_find box text in includes/boxes/quick_find.php
define('BOX_HEADING_SEARCH', 'ʸ');
define('BOX_SEARCH_TEXT', 'ɤϤƾʤõޤ');
define('BOX_SEARCH_ADVANCED_SEARCH', 'ܺٸ');

// specials box text in includes/boxes/specials.php
define('BOX_HEADING_SPECIALS', 'ò');
define('BOX_MORE_SPECIALS', 'ä...');

// reviews box text in includes/boxes/reviews.php
define('BOX_HEADING_REVIEWS', 'ɾ');
define('BOX_REVIEWS_WRITE_REVIEW', 'ξʤˤĤƤνɾ񤭤ޤ?');
define('BOX_REVIEWS_NO_REVIEWS', '߽ɾϤޤ');
define('BOX_REVIEWS_TEXT_OF_5_STARS', '5 %s!');
define('BOX_MORE_REVIEWS', 'ä...');

// shopping_cart box text in includes/boxes/shopping_cart.php
define('BOX_HEADING_SHOPPING_CART', 'åԥ󥰥');
define('BOX_SHOPPING_CART_EMPTY', 'Ȥ϶Ǥ...');
define('BOX_MORE_SHOPPING_CART', 'Ȥ...');

// order_history box text in includes/boxes/order_history.php
define('BOX_HEADING_CUSTOMER_ORDERS', 'ʸ');

// best_sellers box text in includes/boxes/best_sellers.php
define('BOX_HEADING_BESTSELLERS', '٥ȥ顼');
define('BOX_HEADING_BESTSELLERS_IN', '&nbsp;&nbsp;<br>Υڥȥ顼');

// notifications box text in includes/boxes/products_notifications.php
define('BOX_HEADING_NOTIFICATIONS', 'E-MailǤΤ餻');
define('BOX_NOTIFICATIONS_NOTIFY', '<b>%s</b>κǿΤ餻!');
define('BOX_NOTIFICATIONS_NOTIFY_REMOVE', '<b>%s</b>κǿΤ餻ʤ');

// manufacturer box text
define('BOX_HEADING_MANUFACTURER_INFO', '᡼');
define('BOX_MANUFACTURER_INFO_HOMEPAGE', '%s ۡڡ');
define('BOX_MANUFACTURER_INFO_OTHER_PRODUCTS', '¾ξ');

// languages box text in includes/boxes/languages.php
define('BOX_HEADING_LANGUAGES', '');

// currencies box text in includes/boxes/currencies.php
define('BOX_HEADING_CURRENCIES', '̲');

// information box text in includes/boxes/information.php
define('BOX_HEADING_INFORMATION', 'ե᡼');
define('BOX_INFORMATION_PRIVACY', 'ץ饤ХˤĤ');
define('BOX_INFORMATION_CONDITIONS', 'ѵ');
define('BOX_INFORMATION_SHIPPING', 'ʤˤĤ');
define('BOX_INFORMATION_CONTACT', '䤤碌');

// tell a friend box text in includes/boxes/tell_a_friend.php
define('BOX_HEADING_TELL_A_FRIEND', 'ͧãΤ餻');
define('BOX_TELL_A_FRIEND_TEXT', 'ξʤURLͧã˥᡼뤹');

// checkout procedure text
define('CHECKOUT_BAR_DELIVERY',    'ˡ');
define('CHECKOUT_BAR_PAYMENT',     'ʧˡ');
define('CHECKOUT_BAR_CONFIRMATION','ǽǧ');
define('CHECKOUT_BAR_FINISHED',    '³λ!');

// pull down default text
define('PULL_DOWN_DEFAULT', '򤷤Ƥ');
define('TYPE_BELOW', '');

// javascript messages
define('JS_ERROR', 'ϥեǥ顼Ƥޤ!\nιܤƤ:\n\n');

define('JS_REVIEW_TEXT', '* ɾʸϤϾʤƤ ' . REVIEW_TEXT_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_REVIEW_RATING', '* ʤκ򤷤Ƥ\n');

define('JS_GENDER', '* \'\' 򤵤Ƥޤ\n');
define('JS_FIRST_NAME', '* \'̾\' ϾʤƤ ' . ENTRY_FIRST_NAME_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_LAST_NAME', '* \'\' ϾʤƤ ' . ENTRY_LAST_NAME_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_DOB', '* \'ǯ\' ϼηϤƤ: xxxx/xx/xx (ǯ//).\n');
define('JS_EMAIL_ADDRESS', '* \'E-Mail ɥ쥹\' ϾʤƤ ' . ENTRY_EMAIL_ADDRESS_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_ADDRESS', '* \'1\' ϾʤƤ ' . ENTRY_STREET_ADDRESS_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_POST_CODE', '* \'͹ֹ\' ϾʤƤ ' . ENTRY_POSTCODE_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_CITY', '* \'ԶĮ¼\' ϾʤƤ ' . ENTRY_CITY_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_STATE', '* \'ƻܸ\' ޤϤƤ\n');
define('JS_COUNTRY', '* \'\' 򤷤Ƥ');
define('JS_TELEPHONE', '* \'ֹ\' ϾʤƤ ' . ENTRY_TELEPHONE_MIN_LENGTH . ' ʸʾɬפǤ\n');
define('JS_PASSWORD', '* \'ѥ\'  \'ѥɤ\' ϰפƤ ' . ENTRY_PASSWORD_MIN_LENGTH . ' ʸʾɬפǤ\n');

define('JS_ERROR_NO_PAYMENT_MODULE_SELECTED', '* ʸʤΤʧˡ򤷤Ƥ\n');
define('JS_ERROR_SUBMITTED', 'ΥեϴƤޤOkܥ򲡤λޤǤ⤦Ф餯Ԥ');

define('ERROR_NO_PAYMENT_MODULE_SELECTED', '* ʸʤΤʧˡ򤷤Ƥ');

define('CATEGORY_COMPANY', 'Ҿ');
define('CATEGORY_PERSONAL', 'Ŀ;');
define('CATEGORY_ADDRESS', '');
define('CATEGORY_CONTACT', 'Ϣ');
define('CATEGORY_OPTIONS', 'ץ');
define('CATEGORY_PASSWORD', 'ѥ');
define('ENTRY_COMPANY', '/̾:');
define('ENTRY_COMPANY_ERROR', '');
define('ENTRY_COMPANY_TEXT', '');
define('ENTRY_GENDER', ':');
define('ENTRY_GENDER_ERROR', '<span class="entryRequired">ɬפǤ</span>');
define('ENTRY_GENDER_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_FIRST_NAME', '̾:');
define('ENTRY_FIRST_NAME_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_FIRST_NAME_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_FIRST_NAME_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_LAST_NAME', ':');
define('ENTRY_LAST_NAME_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_LAST_NAME_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_LAST_NAME_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_DATE_OF_BIRTH', 'ǯ:');
define('ENTRY_DATE_OF_BIRTH_ERROR', '<span class="entryError">(. 1970/05/21)</span>');
define('ENTRY_DATE_OF_BIRTH_TEXT', '<small>(. 1970/05/21)</small> <span class="entryRequired">ɬ</span>');
define('ENTRY_EMAIL_ADDRESS', 'E-Mail ɥ쥹:');
define('ENTRY_EMAIL_ADDRESS_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_EMAIL_ADDRESS_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_EMAIL_ADDRESS_CHECK_ERROR', '<span class="entryError">Ϥ줿 E-Mail ɥ쥹Ǥ!</span>');
define('ENTRY_EMAIL_ADDRESS_ERROR_EXISTS', '<span class="entryError">E-Mail ɥ쥹ϤǤ¸ߤƤޤ!</span>');
define('ENTRY_EMAIL_ADDRESS_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_STREET_ADDRESS', '꣱:');
define('ENTRY_STREET_ADDRESS_ERROR', ';<span class="entryError">ʤƤ ' . ENTRY_STREET_ADDRESS_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_STREET_ADDRESS_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_SUBURB', 'ꣲ:');
define('ENTRY_SUBURB_ERROR', '');
define('ENTRY_SUBURB_TEXT', '');
define('ENTRY_POST_CODE', '͹ֹ:');
define('ENTRY_POST_CODE_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_POSTCODE_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_POST_CODE_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_CITY', 'ԶĮ¼:');
define('ENTRY_CITY_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_CITY_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_CITY_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_STATE', 'ƻܸ:');
define('ENTRY_STATE_ERROR', '<span class="entryError">ɬ</span>');
define('ENTRY_STATE_TEXT', '<span class="entryRequired">ɬ</span');
define('ENTRY_COUNTRY', '̾:');
define('ENTRY_COUNTRY_ERROR', '');
define('ENTRY_COUNTRY_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_TELEPHONE_NUMBER', 'ֹ:');
define('ENTRY_TELEPHONE_NUMBER_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_TELEPHONE_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_TELEPHONE_NUMBER_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_FAX_NUMBER', 'եֹ:');
define('ENTRY_FAX_NUMBER_ERROR', '');
define('ENTRY_FAX_NUMBER_TEXT', '');
define('ENTRY_NEWSLETTER', '᡼ޥ:');
define('ENTRY_NEWSLETTER_TEXT', '');
define('ENTRY_NEWSLETTER_YES', 'ɤ');
define('ENTRY_NEWSLETTER_NO', 'ɤʤ');
define('ENTRY_NEWSLETTER_ERROR', '');
define('ENTRY_PASSWORD', 'ѥ:');
define('ENTRY_PASSWORD_CONFIRMATION', 'ѥɤ:');
define('ENTRY_PASSWORD_CONFIRMATION_TEXT', '<span class="entryRequired">ɬ</span>');
define('ENTRY_PASSWORD_ERROR', '<span class="entryError">ʤƤ ' . ENTRY_PASSWORD_MIN_LENGTH . ' ʸ</span>');
define('ENTRY_PASSWORD_TEXT', '<span class="entryRequired">ɬ</span>');
define('PASSWORD_HIDDEN', '********');

// constants for use in tep_prev_next_display function
define('TEXT_RESULT_PAGE', 'ڡ:');
define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> 뾦ʤΤ)');
define('TEXT_DISPLAY_NUMBER_OF_ORDERS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> ʸΤ)');
define('TEXT_DISPLAY_NUMBER_OF_REVIEWS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> ɾΤ)');
define('TEXT_DISPLAY_NUMBER_OF_PRODUCTS_NEW', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> 뿷徦ʤΤ)');
define('TEXT_DISPLAY_NUMBER_OF_SPECIALS', '<b>%d</b> - <b>%d</b> ܤɽ (<b>%d</b> òʤΤ)');

define('PREVNEXT_TITLE_FIRST_PAGE', 'ǽΥڡ');
define('PREVNEXT_TITLE_PREVIOUS_PAGE', 'ڡ');
define('PREVNEXT_TITLE_NEXT_PAGE', 'ڡ');
define('PREVNEXT_TITLE_LAST_PAGE', 'ǸΥڡ');
define('PREVNEXT_TITLE_PAGE_NO', 'ڡ %d');
define('PREVNEXT_TITLE_PREV_SET_OF_NO_PAGE', ' %d ڡ');
define('PREVNEXT_TITLE_NEXT_SET_OF_NO_PAGE', ' %d ڡ');
define('PREVNEXT_BUTTON_FIRST', '&lt;&lt;ǽ');
define('PREVNEXT_BUTTON_PREV', '[&lt;&lt;&nbsp;ڡ]');
define('PREVNEXT_BUTTON_NEXT', '[ڡ&nbsp;&gt;&gt;]');
define('PREVNEXT_BUTTON_LAST', 'Ǹ&gt;&gt;');

define('TEXT_SSL_PROTECTION', 'ΥڡSSLݸƤޤ');

define('IMAGE_BUTTON_ADD_ADDRESS', 'ɥ쥹ɲ');
define('IMAGE_BUTTON_ADDRESS_BOOK', 'ɥ쥹Ģ');
define('IMAGE_BUTTON_BACK', '');
define('IMAGE_BUTTON_CHANGE_ADDRESS', 'ɥ쥹ѹ');
define('IMAGE_BUTTON_CHECKOUT', '쥸˿ʤ');
define('IMAGE_BUTTON_CONFIRM_ORDER', 'ʸ!');
define('IMAGE_BUTTON_CONTINUE', '˿ʤ');
define('IMAGE_BUTTON_CONTINUE_SHOPPING', 'åԥ󥰤³');
define('IMAGE_BUTTON_DELETE', '');
define('IMAGE_BUTTON_EDIT_ACCOUNT', 'Խ');
define('IMAGE_BUTTON_HISTORY', 'ʸ');
define('IMAGE_BUTTON_LOGIN', '');
define('IMAGE_BUTTON_IN_CART', 'Ȥ');
define('IMAGE_BUTTON_NOTIFICATIONS', 'Τ餻');
define('IMAGE_BUTTON_QUICK_FIND', 'ʸ');
define('IMAGE_BUTTON_REMOVE_NOTIFICATIONS', 'Τ餻ä');
define('IMAGE_BUTTON_REVIEWS', 'ɾɤ');
define('IMAGE_BUTTON_SEARCH', '');
define('IMAGE_BUTTON_SHIPPING_OPTIONS', 'ץ');
define('IMAGE_BUTTON_TELL_A_FRIEND', 'ͧãΤ餻');
define('IMAGE_BUTTON_UPDATE', '');
define('IMAGE_BUTTON_UPDATE_CART', 'Ȥ򹹿');
define('IMAGE_BUTTON_WRITE_REVIEW', 'ɾ');
define('IMAGE_BUTTON_GETA_RESULTS_PREV', 'Prev');
define('IMAGE_BUTTON_GETA_RESULTS_MORE', 'More');

define('ICON_ARROW_RIGHT', 'ɽ'); //more
define('ICON_CART', 'Ȥ');
define('ICON_WARNING', 'ٹ');

define('TEXT_GREETING_PERSONAL', 'ä㤤ޤ<span class="greetUser">%s </span> <a href="%s"><u>徦</u></a> ˤʤޤ');
define('TEXT_GREETING_PERSONAL_RELOGON', '<small>⤷ʤ %s ǤʤСȾϤ <a href="%s"><u></u></a> Ƥ</small>');
define('TEXT_GREETING_GUEST', '<span class="greetUser">Ȥ</span>ä㤤ޤ <a href="%s"><u></u></a>ޤ Ȥ⡢<a href="%s"><u></u></a>ޤ');

define('TEXT_SORT_PRODUCTS', 'ʤ¤ؤ ');
define('TEXT_DESCENDINGLY', '߽');
define('TEXT_ASCENDINGLY', '');
define('TEXT_BY', ' &sim; ');   //by

define('TEXT_REVIEW_BY', 'Ƽ %s');
define('TEXT_REVIEW_WORD_COUNT', '%s ʸ');
define('TEXT_REVIEW_RATING', 'ɾ: %s [%s]');
define('TEXT_REVIEW_DATE_ADDED', ': %s');
define('TEXT_NO_REVIEWS', 'ޤɾϤޤ...');

define('TEXT_NO_NEW_PRODUCTS', '߾ʤϿƤޤ...');

define('TEXT_UNKNOWN_TAX_RATE', 'Ψ');

define('TEXT_REQUIRED', 'ɬ');

define('TEXT_TIME_SPECIFY', 'Ϥ: '); // add for Japanese update

define('ERROR_TEP_MAIL', '<font face="Verdana, Arial" size="2" color="#ff0000"><b><small>顼:</small> ꤵ줿SMTP Ф᡼Ǥޤ php.ini SMTP ǧơɬפнƤ</b></font>');
define('WARNING_INSTALL_DIRECTORY_EXISTS', 'ٹ: 󥹥ȡ롦ǥ쥯ȥ(/install)¸ߤޤޤǤ: ' . dirname($HTTP_SERVER_VARS['SCRIPT_FILENAME']) . '/install. ǥ쥯ȥϥƥδޤΤǺƤ');
define('WARNING_CONFIG_FILE_WRITEABLE', 'ٹ: ե(/includes/configure.php)˽񤭹߸¤ꤵ줿ޤޤǤ: ' . dirname($HTTP_SERVER_VARS['SCRIPT_FILENAME']) . '/includes/configure.php. եΥ桼¤ѹƤ');
define('WARNING_SESSION_DIRECTORY_NON_EXISTENT', 'ٹ: å󡦥ǥ쥯ȥ꤬¸ߤޤ: ' . tep_session_save_path() . '. åѤ뤿˥ǥ쥯ȥƤ');
define('WARNING_SESSION_DIRECTORY_NOT_WRITEABLE', 'ٹ: å󡦥ǥ쥯ȥ˽񤭹ߤǤޤ: ' . tep_session_save_path() . '. å󡦥ǥ쥯ȥ桼¤ꤷƤ');
define('WARNING_SESSION_AUTO_START', 'ٹ: å󡦥ȥȤͭˤʤäƤޤեphp.iniˤ̵ꤷ֥ФꥹȤƤ');
define('WARNING_DOWNLOAD_DIRECTORY_NON_EXISTENT', 'ٹ: 侦ʥǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_DOWNLOAD . '. Υǥ쥯ȥʤ侦ʤμ谷ޤ');

define('TEXT_CCVAL_ERROR_INVALID_DATE', '쥸åȥͭ¤ޤ' . "\n" . 'ǧ⤦ϤƤ');
define('TEXT_CCVAL_ERROR_INVALID_NUMBER', '쥸åȥɥʥСޤ' . "\n" . 'ǧ⤦ϤƤ');
define('TEXT_CCVAL_ERROR_UNKNOWN_CARD', 'Ϥ쥸åȥɥʥСκǽ4: %s Ǥ' . "\n" . 'ʥС礳Υɤμ谷ޤ' . "\n" . 'ְäƤϤǧ⤦ϤƤ');

define('MODULE_PAYMENT_COD_TEXT_EMAIL_FOOTER', '');

/*
  The following copyright announcement can only be
  appropriately modified or removed if the layout of
  the site theme has been modified to distinguish
  itself from the default osCommerce-copyrighted
  theme.

  For more information please read the following
  Frequently Asked Questions entry on the osCommerce
  support site:

  http://www.oscommerce.com/community.php/faq,26/q,50

  Please leave this comment intact together with the
  following copyright announcement.
*/
define('FOOTER_TEXT_BODY', 'Copyright &copy; 2004 <a href="http://www.koshoten.net/" target="_blank">Koshoten.net2</a><br>Powered by <a href="http://www.oscommerce.com/" target="_blank">osCommerce</a>');

define('EMAIL_SIGNATURE', '');
?>